@@ -5,18 +5,18 @@
 #'
 #' @param data For advanced use only. The default `NULL` automatically
 #'   finds the "current" data frames.
-#' @param vars Deprecated; please use data instead.
+#' @param vars `r lifecycle::badge("defunct")`
 #' @seealso [groups()] and [group_vars()] for retrieving the grouping
 #'   variables outside selection contexts.
 #'
 #' @examples
-#' gdf <- iris %>% group_by(Species)
-#' gdf %>% select(group_cols())
+#' gdf <- iris |> group_by(Species)
+#' gdf |> select(group_cols())
 #'
 #' # Remove the grouping variables from mutate selections:
-#' gdf %>% mutate_at(vars(-group_cols()), `/`, 100)
+#' gdf |> mutate_at(vars(-group_cols()), `/`, 100)
 #' # -> No longer necessary with across()
-#' gdf %>% mutate(across(everything(), ~ . / 100))
+#' gdf |> mutate(across(everything(), ~ . / 100))
 #' @export
 group_cols <- function(vars = NULL, data = NULL) {
   # So group_cols() continues to work in _at() helpers.
@@ -31,14 +31,15 @@ group_cols <- function(vars = NULL, data = NULL) {
 
 group_cols_legacy <- function(vars = NULL) {
   if (!is.null(vars)) {
-    lifecycle::deprecate_warn(
-      "1.0.0", "group_cols(vars = )",
-      details = "Use `data` with entire dataframe instead",
-      always = TRUE
+    lifecycle::deprecate_stop(
+      "1.0.0",
+      "group_cols(vars = )",
+      details = "Use `data` with entire dataframe instead"
     )
   }
 
-  vars <- vars %||% tidyselect::peek_vars()
+  vars <- tidyselect::peek_vars()
+
   if (is_sel_vars(vars)) {
     matches <- match(vars %@% groups, vars)
     if (anyNA(matches)) {
