@@ -9,8 +9,14 @@ test_that("fun_list is merged with new args", {
 test_that("funs() works with namespaced calls", {
   withr::local_options(lifecycle_verbosity = "quiet")
 
-  expect_identical(summarise_all(mtcars, funs(base::mean(.))), summarise_all(mtcars, funs(mean(.))))
-  expect_identical(summarise_all(mtcars, funs(base::mean)), summarise_all(mtcars, funs(mean(.))))
+  expect_identical(
+    summarise_all(mtcars, funs(base::mean(.))),
+    summarise_all(mtcars, funs(mean(.)))
+  )
+  expect_identical(
+    summarise_all(mtcars, funs(base::mean)),
+    summarise_all(mtcars, funs(mean(.)))
+  )
 })
 
 test_that("funs() found in local environment", {
@@ -46,7 +52,10 @@ test_that("funs() can be merged with new arguments", {
   withr::local_options(lifecycle_verbosity = "quiet")
 
   fns <- funs(foo(.))
-  expect_identical(as_fun_list(fns, current_env(), foo = 1L), funs(foo(., foo = 1L)))
+  expect_identical(
+    as_fun_list(fns, current_env(), foo = 1L),
+    funs(foo(., foo = 1L))
+  )
 })
 
 enfun <- function(.funs, ...) {
@@ -83,33 +92,15 @@ test_that("can enfun() purrr-style lambdas", {
   my_mean <- as_function(~ mean(.x))
   res <- enfun(~ mean(.x))
   expect_equal(length(res), 1L)
-  expect_true(typeof(res[[1]]) == "closure")
-})
-
-test_that("funs_ works", {
-  withr::local_options(lifecycle_verbosity = "quiet")
-
-  expect_equal(
-    funs(mean),
-    funs_(list(~ mean))
-  )
-
-  expect_equal(
-    funs_(list("mean")),
-    funs_(list(`environment<-`(~ mean, baseenv()))),
-    ignore_formula_env = TRUE
-  )
-
-  expect_equal(
-    funs(mean(.)),
-    funs_(list(~ mean(.)))
-  )
+  expect_type(res[[1]], "closure")
 })
 
 test_that("as_fun_list() auto names chr vectors (4307)", {
-  expect_identical(
-    data.frame(x = 1:10) %>% summarise_at("x", c("mean", "sum")),
-    data.frame(x = 1:10) %>% summarise(mean = mean(x), sum = sum(x))
+  df <- data.frame(x = 1:10)
+
+  expect_named(
+    summarise_at(df, "x", c("mean", "sum")),
+    c("mean", "sum")
   )
 })
 
@@ -123,8 +114,9 @@ test_that("funs() give meaningful error messages", {
   withr::local_options(lifecycle_verbosity = "quiet")
 
   expect_snapshot({
-    (expect_error(funs(function(si) { mp[si] })))
-    (expect_error(funs(~ mp[.]))  )
+    (expect_error(funs(function(si) {
+      mp[si]
+    })))
+    (expect_error(funs(~ mp[.])))
   })
-
 })
