@@ -6,15 +6,21 @@ test_that("rename() handles deprecated `.data` pronoun", {
 test_that("arguments to rename() don't match vars_rename() arguments (#2861)", {
   df <- tibble(a = 1)
   expect_identical(rename(df, var = a), tibble(var = 1))
-  expect_identical(rename(group_by(df, a), var = a), group_by(tibble(var = 1), var))
+  expect_identical(
+    rename(group_by(df, a), var = a),
+    group_by(tibble(var = 1), var)
+  )
   expect_identical(rename(df, strict = a), tibble(strict = 1))
-  expect_identical(rename(group_by(df, a), strict = a), group_by(tibble(strict = 1), strict))
+  expect_identical(
+    rename(group_by(df, a), strict = a),
+    group_by(tibble(strict = 1), strict)
+  )
 })
 
 test_that("rename() to UTF-8 column names", {
   skip_if_not(l10n_info()$"UTF-8")
 
-  df <- tibble(a = 1) %>% rename("\u5e78" := a)
+  df <- tibble(a = 1) |> rename("\u5e78" := a)
   expect_equal(colnames(df), "\u5e78")
 })
 
@@ -35,7 +41,7 @@ test_that("rename preserves grouping", {
 
 test_that("can rename with duplicate columns", {
   df <- tibble(x = 1, x = 2, y = 1, .name_repair = "minimal")
-  expect_named(df %>% rename(x2 = 2), c("x", "x2", "y"))
+  expect_named(df |> rename(x2 = 2), c("x", "x2", "y"))
 })
 
 test_that("rename() ignores duplicates", {
@@ -47,20 +53,26 @@ test_that("rename() ignores duplicates", {
 
 test_that("can select columns", {
   df <- tibble(x = 1, y = 2)
-  expect_named(df %>% rename_with(toupper, 1), c("X", "y"))
+  expect_named(df |> rename_with(toupper, 1), c("X", "y"))
 
   df <- tibble(x = 1, y = 2)
-  expect_named(df %>% rename_with(toupper, x), c("X", "y"))
+  expect_named(df |> rename_with(toupper, x), c("X", "y"))
 })
 
 test_that("passes ... along", {
   df <- tibble(x = 1, y = 2)
-  expect_named(df %>% rename_with(gsub, 1, pattern = "x", replacement = "X"), c("X", "y"))
+  expect_named(
+    df |> rename_with(gsub, 1, pattern = "x", replacement = "X"),
+    c("X", "y")
+  )
 })
 
 test_that("can't create duplicated names", {
   df <- tibble(x = 1, y = 2)
-  expect_error(df %>% rename_with(~ rep_along(.x, "X")), class = "vctrs_error_names")
+  expect_error(
+    df |> rename_with(~ rep_along(.x, "X")),
+    class = "vctrs_error_names"
+  )
 })
 
 test_that("`.fn` result type is checked (#6561)", {
